@@ -39,8 +39,8 @@ class ENCoM(ENM):
                                  long-range interaction (V4)
         """
 
-    def __init__(self, pdb_file, kr=1000, ktheta=10000, kphi=10000, epsi=0.01, apply_epsi=False, interact_const=10,
-                 null_interact_const=0.1,
+    def __init__(self, pdb_file, kr=1000, ktheta=10000, kphi=10000, epsi=0.01, apply_epsi=False, interact_const=3,
+                 null_interact_const=1,
                  power_dependenceV4=4, interact_mat=None, use_stem=False, kphi1=1, kphi3=0.5, bfact_params=False,
                  added_atypes=None, added_massdef=None, atypes_list=None, massdef_list=None, verbose=False, solve=True,
                  ignore_hetatms=False, use_pickle=False, solve_mol=True, one_mass=False, interact_level=3,
@@ -116,8 +116,8 @@ class ENCoM(ENM):
             self.ktheta = 80000
             self.kphi = 20000
             self.epsi = 0.08
-            self.ic = 80,
-            self.nic = 0.00125
+            self.ic = 80
+            self.nic = 0.0125
         if self.bfact_params: # optimal parameters for b-factor correlation from Frappier and Najmanovich 2014
             self.kr = 1000
             self.ktheta = 100000
@@ -234,6 +234,8 @@ class ENCoM(ENM):
         assert isinstance(other, ENCoM)
         if not self.mol.solved:
             self.mol.solve()
+        self.eigfreqs = None
+        self.sq_eigvecs = None
         masses = self.mol.masses
         connect = self.mol.connect
         bends = self.mol.bends
@@ -258,6 +260,8 @@ class ENCoM(ENM):
         assert isinstance(other, ENCoM)
         if not self.mol.solved:
             self.mol.solve()
+        self.eigfreqs = None
+        self.sq_eigvecs = None
         masses = self.mol.masses
         connect = self.mol.connect
         bends = self.mol.bends
